<?php 
/*
 * WAO UPDATE. LOGICA PARA LA ACTUALIZACION DEL PLUGIN
 * https://rudrastyh.com/wordpress/self-hosted-plugin-update.html
*/

//add_filter( 'plugins_api', 'waosmUpdate', 20, 3);
/*
 * $res empty at this step
 * $action 'plugin_information'
 * $args stdClass Object ( [slug] => woocommerce [is_ssl] => [fields] => Array ( [banners] => 1 [reviews] => 1 [downloaded] => [active_installs] => 1 ) [per_page] => 24 [locale] => en_US )
 */
function waosmUpdate( $res, $action, $args ){

	// do nothing if this is not about getting plugin information
	if( 'plugin_information' !== $action ) {
		return $res;
	}

	// do nothing if it is not our plugin
	if( plugin_basename( __DIR__ ) !== $args->slug ) {
		return $res;
	}
	// info.json is the file with the actual plugin information on your server
	$remote = wp_remote_get( 
		'https://download.winandoffice.com/Install/pluginWaoUpdates/waosegundoemail/pluginwaosmversion.json', 
		array(
			'timeout' => 10,
			'headers' => array('Accept' => 'application/json') 
		)
	);

	// do nothing if we don't get the correct response from the server
	if(is_wp_error( $remote )|| 200 !== wp_remote_retrieve_response_code( $remote )|| empty( wp_remote_retrieve_body( $remote ))) {
		return $res;	
	}

	$remote = json_decode( wp_remote_retrieve_body( $remote ) );
	
	$res = new stdClass();
	$res->name = $remote->name;
	$res->slug = $remote->slug;
	$res->author = $remote->author;
	$res->author_profile = $remote->author_profile;
	$res->version = $remote->version;
	$res->tested = $remote->tested;
	$res->requires = $remote->requires;
	$res->requires_php = $remote->requires_php;
	$res->download_link = $remote->download_url;
	$res->trunk = $remote->download_url;
	$res->last_updated = $remote->last_updated;
	$res->sections = array(
		'description' => $remote->sections->description,
		'installation' => $remote->sections->installation,
		'changelog' => $remote->sections->changelog
		// you can add your custom sections (tabs) here
	);
	// in case you want the screenshots tab, use the following HTML format for its content:
	// <ol><li><a href="IMG_URL" target="_blank"><img src="IMG_URL" alt="CAPTION" /></a><p>CAPTION</p></li></ol>


	if( ! empty( $remote->sections->screenshots ) ) {
		$res->sections[ 'screenshots' ] = $remote->sections->screenshots;
	}

	$res->banners = array(
		'low' => $remote->banners->low,
		'high' => $remote->banners->high
	);
	
	return $res;

}

//add_filter( 'site_transient_update_plugins', 'waosm_push_update' );
 
function waosm_push_update( $transient ){
 
	if ( empty( $transient->checked ) ) {
		return $transient;
	}

	$remote = wp_remote_get( 
		'https://download.winandoffice.com/Install/pluginWaoUpdates/waosegundoemail/pluginwaosmversion.json',
		array(
			'timeout' => 10,
			'headers' => array(
				'Accept' => 'application/json'
			)
		)
	);
	if(is_wp_error( $remote )|| 200 !== wp_remote_retrieve_response_code( $remote )|| empty( wp_remote_retrieve_body( $remote ))) {
		return $transient;	
	}
	
	$remote = json_decode( wp_remote_retrieve_body( $remote ) );
 
		// your installed plugin version should be on the line below! You can obtain it dynamically of course 
//	$this->version="2.5.34";
/*	if(
		$remote
		&& version_compare( MY_PLUGIN_VERSION, $remote->version, '<' )
		&& version_compare( $remote->requires, get_bloginfo( 'version' ), '<' )
		&& version_compare( $remote->requires_php, PHP_VERSION, '<' )
	) {*/

	if($remote&& version_compare( WAOSM_PLUGIN_VERSION, $remote->version, '<' )) {
		$res = new stdClass();
		$res->slug = $remote->slug;
		//$res->plugin = plugin_basename( __FILE__ ); // it could be just YOUR_PLUGIN_SLUG.php if your plugin doesn't have its own directory
		$res->plugin = "waosegundoemail/waosegundoemail.php";
		$res->new_version = $remote->version;
		$res->tested = $remote->tested;
		$res->package = $remote->download_url;
		$res->details_url = $remote->details_url;
		$transient->response[ $res->plugin ] = $res;
		
		//$transient->checked[$res->plugin] = $remote->version;
	}
 
	return $transient;

}

if(!is_bool(get_option('activaupdate'))){
	if(get_option('activaupdate')=='yes'){
		add_filter( 'plugins_api', 'waosmUpdate', 20, 3);
		add_filter( 'site_transient_update_plugins', 'waosm_push_update' );
		//include("wao-update.php");
	}
}

// Agrega un filtro para modificar los metadatos de la fila del plugin
add_filter('plugin_row_meta', 'custom_plugin_row_meta_second_email', 10, 4);

function custom_plugin_row_meta_second_email($meta, $plugin_file, $plugin_data, $status) {
    // Reemplaza el enlace predeterminado con tu enlace personalizado
    if ($plugin_file === 'waosegundoemail/waosegundoemail.php') {
        $url = 'plugin-install.php?tab=plugin-information&plugin=waosegundoemail&section=description&TB_iframe=true&width=772&height=839';
        $meta[] = '<a href="' . esc_url($url) . '" class="thickbox open-plugin-details-modal">' . esc_html__('View details', 'wao-tiendas') . '</a>';
    }
    return $meta;
}
